@@ -18,34 +18,31 @@
 ******************************************************************/
 
 #include "kfindtreeview.h"
-
 #include "kfinddlg.h"
 
-#include <QTextStream>
-#include <QTextCodec>
-#include <QFileInfo>
-#include <QClipboard>
-#include <QHeaderView>
 #include <QApplication>
+#include <QClipboard>
 #include <QDate>
+#include <QFileDialog>
+#include <QFileInfo>
+#include <QHeaderView>
 #include <QMenu>
+#include <QMimeData>
+#include <QTextCodec>
+#include <QTextStream>
 
 #include <KActionCollection>
-#include <QFileDialog>
-#include <krun.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
-#include <kiconloader.h>
-#include <kglobalsettings.h>
-#include <kjobwidgets.h>
 #include <KFileItemActions>
 #include <KFileItemListProperties>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KPropertiesDialog>
+#include <KRun>
 
-#include <kio/netaccess.h>
-#include <kio/copyjob.h>
-#include <kio/deletejob.h>
-#include <kio/jobuidelegate.h>
+#include <KIO/CopyJob>
+#include <KIO/DeleteJob>
+#include <KIO/JobUiDelegate>
 #include <KIO/OpenFileManagerWindowJob>
 #include <kio_version.h>
 
@@ -331,7 +328,6 @@ KFindTreeView::KFindTreeView(QWidget *parent, KfindDlg *findDialog)
     connect(this, &KFindTreeView::customContextMenuRequested, this, &KFindTreeView::contextMenuRequested);
 
     //Mouse single/double click settings
-    connect(KGlobalSettings::self(), &KGlobalSettings::settingsChanged, this, &KFindTreeView::reconfigureMouseSettings);
     reconfigureMouseSettings();
 
     // TODO: this is a workaround until  Qt-issue 176832 has been fixed (from Dolphin)
@@ -639,7 +635,7 @@ void KFindTreeView::reconfigureMouseSettings()
     disconnect(SIGNAL(clicked(QModelIndex)));
     disconnect(SIGNAL(doubleClicked(QModelIndex)));
 
-    if (KGlobalSettings::singleClick()) {
+    if (m_kfindDialog->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick)) {
         connect(this, &KFindTreeView::clicked, this, &KFindTreeView::slotExecute);
     } else {
         connect(this, &KFindTreeView::doubleClicked, this, &KFindTreeView::slotExecute);
